@@ -1,4 +1,7 @@
+import pickle
+
 from actionpack.actions import ReadBytes
+from actionpack.utils import pickleable
 
 from oslash import Left
 from oslash import Right
@@ -7,14 +10,17 @@ from unittest import TestCase
 from unittest.mock import patch
 
 
-class ReadInputTest(TestCase):
+class ReadBytesTest(TestCase):
 
     contents = 'some file contents.'.encode()
 
+    def setUp(self):
+        self.action = ReadBytes(__file__)
+
     @patch('pathlib.Path.read_bytes')
     def test_can_ReadBytes(self, mock_input):
         mock_input.return_value = self.contents
-        result = ReadBytes(__file__).perform()
+        result = self.action.perform()
         self.assertIsInstance(result, Right)
         self.assertEqual(result.value, self.contents)
 
@@ -30,3 +36,10 @@ class ReadInputTest(TestCase):
         self.assertIsInstance(directory_result, Left)
         self.assertIsInstance(directory_result.value, IsADirectoryError)
 
+    def test_can_pickle(self):
+        pickled = pickleable(self.action)
+        unpickled = pickle.loads(pickled)
+
+        self.assertTrue(pickleable(self.action))
+        self.assertEqual(unpickled.__dict__, self.action.__dict__)
+
