@@ -1,5 +1,8 @@
+import pickle
+
 from actionpack.actions import MakeRequest
 from actionpack.actions import RetryPolicy
+from actionpack.utils import pickleable
 from tests.actionpack.actions import FakeResponse
 
 from oslash import Left
@@ -11,14 +14,16 @@ from unittest.mock import patch
 
 class RetryPolicyTest(TestCase):
 
+    def setUp(self):
+        self.max_retries = 2
+        self.action =  RetryPolicy(MakeRequest('GET', 'http://localhost'), max_retries=self.max_retries)
+
     @patch('requests.Session.send')
     def test_can_enact_RetryPolicy(self, mock_session_send):
         mock_session_send.side_effect = Exception('something went wrong :/')
-        max_retries = 2
-        action = RetryPolicy(MakeRequest('GET', 'http://localhost'), max_retries=max_retries)
-        result = action.perform()
+        result = self.action.perform()
 
-        self.assertEqual(action.retries, max_retries)
+        self.assertEqual(self.action.retries, self.max_retries)
         self.assertIsInstance(result, Left)
         self.assertIsInstance(result.value, RetryPolicy.Expired)
 
@@ -28,9 +33,18 @@ class RetryPolicyTest(TestCase):
             Exception('something went wrong :/'),
             FakeResponse('something went right :)'.encode())
         ]
-        max_retries = 2
-        action = RetryPolicy(MakeRequest('GET', 'http://localhost'), max_retries=max_retries)
-        result = action.perform()
+        result = self.action.perform()
 
-        self.assertEqual(action.retries, 1)
+        self.assertEqual(self.action.retries, 1)
         self.assertIsInstance(result, Right)
+
+    @patch('requests.Session.send')
+    def test_can_pickle(self, mock_session_send):
+        mock_session_send.side_effect = NotImplemented
+        self.assertTrue(pickleable(self.action))
+
+        pickled = pickleable(self.action)
+        unpickled = pickle.loads(pickled)
+
+        self.assertTrue(pickleable(self.action))
+        self.assertEqual(unpickled.__dict__, self.action.__dict__)
